|Travis|_ |Coveralls|_ |Docs|_

.. |Travis| image:: https://api.travis-ci.org/cjw296/sybil.svg?branch=master
.. _Travis: https://travis-ci.org/cjw296/sybil

.. |Coveralls| image:: https://coveralls.io/repos/cjw296/sybil/badge.svg?branch=master
.. _Coveralls: https://coveralls.io/r/cjw296/sybil?branch=master

.. |Docs| image:: https://readthedocs.org/projects/sybil/badge/?version=latest
.. _Docs: http://sybil.readthedocs.org/en/latest/

Sybil
=====

Automated testing for the examples in your documentation.

The latest documentation can be found at:
http://sybil.readthedocs.org/en/latest/

Development takes place here:
https://github.com/cjw296/sybil/
